aboutsummaryrefslogtreecommitdiff
path: root/keyboards/handwired/evk
diff options
context:
space:
mode:
authorRyan <[email protected]>2024-05-03 15:21:29 +1000
committerGitHub <[email protected]>2024-05-03 15:21:29 +1000
commitd09a06a1b354760fd0e64a453abade972900e885 (patch)
tree88d94640f4507ac8d7f570607423825bec3c6f89 /keyboards/handwired/evk
parent5426a7a129acf2ff5c8b435014747f1238e17965 (diff)
downloadqmk_firmware-d09a06a1b354760fd0e64a453abade972900e885.tar.gz
qmk_firmware-d09a06a1b354760fd0e64a453abade972900e885.zip
Update GPIO API usage in keyboard code (#23361)
Diffstat (limited to 'keyboards/handwired/evk')
-rw-r--r--keyboards/handwired/evk/v1_3/v1_3.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/keyboards/handwired/evk/v1_3/v1_3.c b/keyboards/handwired/evk/v1_3/v1_3.c
index 7c68893968..a568ba3f86 100644
--- a/keyboards/handwired/evk/v1_3/v1_3.c
+++ b/keyboards/handwired/evk/v1_3/v1_3.c
@@ -23,22 +23,22 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
// runs once when the firmware starts up
void matrix_init_kb(void) {
// Set the LEDs pins
- setPinOutput(D5); // Layer 1 Status LED
+ gpio_set_pin_output(D5); // Layer 1 Status LED
matrix_init_user();
}
// Set LED based on layer
__attribute__((weak)) layer_state_t layer_state_set_user(layer_state_t state) {
- writePin(D5, layer_state_cmp(state, 1));
+ gpio_write_pin(D5, layer_state_cmp(state, 1));
return state;
}
bool led_update_kb(led_t led_state) {
bool res = led_update_user(led_state);
if (res) {
- // writePin sets the pin high for 1 and low for 0.
- writePin(D4, led_state.caps_lock);
+ // gpio_write_pin sets the pin high for 1 and low for 0.
+ gpio_write_pin(D4, led_state.caps_lock);
}
return res;
}